AsyncFileReader
===============

.. currentmodule:: hdfs_native

.. autoclass:: AsyncFileReader
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~AsyncFileReader.size

   .. rubric:: Methods Summary

   .. autosummary::

      ~AsyncFileReader.close
      ~AsyncFileReader.read
      ~AsyncFileReader.read_range
      ~AsyncFileReader.read_range_stream
      ~AsyncFileReader.readable
      ~AsyncFileReader.readall
      ~AsyncFileReader.seek
      ~AsyncFileReader.seekable
      ~AsyncFileReader.tell

   .. rubric:: Attributes Documentation

   .. autoattribute:: size

   .. rubric:: Methods Documentation

   .. automethod:: close
   .. automethod:: read
   .. automethod:: read_range
   .. automethod:: read_range_stream
   .. automethod:: readable
   .. automethod:: readall
   .. automethod:: seek
   .. automethod:: seekable
   .. automethod:: tell
